#!/bin/bash
#
# Panel Service

PATH=$HOME/.docker/cli-plugins:/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin

config_panel() {
  echo -ne "\n* Configuring /federated/apps/panel container.."
  spin &
  SPINPID=$!

  if [ ! -d "/federated/apps/panel" ]; then
    mkdir -p /federated/apps/panel
  fi

cat > /federated/apps/panel/docker-compose.yml <<EOF
version: '3.7'

services:
  panel:
    image: wheelybird/ldap-user-manager:\${IMAGE_VERSION}
    container_name: panel
    hostname: panel.$DOMAIN
    domainname: $DOMAIN
    restart: always
    networks:
      federated:
        ipv4_address: 172.99.0.23
    env_file:
      - ./.env
    labels:
      - "traefik.enable=true"
      - "traefik.http.routers.panel.rule=Host(\`panel.$DOMAIN\`)"
      - "traefik.http.routers.panel.entrypoints=websecure"
      - "traefik.http.routers.panel.tls.certresolver=letsencrypt"

networks:
  federated:
    external: true
EOF

LDAP_SECRET=`cat /federated/apps/ldap/.ldap.secret`

cat > /federated/apps/panel/.env <<EOF
IMAGE_VERSION="v1.10"
SERVER_HOSTNAME=panel.$DOMAIN
LDAP_URI=ldap://ldap.$DOMAIN
LDAP_BASE_DN=dc=federatedcomputer,dc=cloud
LDAP_REQUIRE_STARTTLS=true
LDAP_ADMINS_GROUP=admins
LDAP_ADMIN_BIND_DN=cn=admin,dc=federatedcomputer,dc=cloud
LDAP_ADMIN_BIND_PWD=$LDAP_SECRET
LDAP_ACCOUNT_ADDITIONAL_OBJECTCLASSES=PostfixBookMailAccount
LDAP_ACCOUNT_ADDITIONAL_ATTRIBUTES=mailEnabled:Mail Enabled:TRUE,mailAlias+:Email aliases
EMAIL_DOMAIN=$DOMAIN
USERNAME_FORMAT={first_name}.{last_name}
SITE_NAME=$COMPANY User Manager
SMTP_HOSTNAME=mail.$DOMAIN
SMTP_USERNAME=admin
SMTP_PASSWORD=$ADMINPASS
EMAIL_FROM_ADDRESS=admin@$DOMAIN
#SMTP_USE_TLS=true
NO_HTTPS=true
EOF
chmod 600 /federated/apps/panel/.env
 
kill -9 $SPINPID &> /dev/null
echo -ne "done."
}
start_panel() {
  # Grab the container IP from docker-compose above
  SERVICE_IP=`grep ipv4_address /federated/apps/panel/docker-compose.yml | awk '{ print $2 }'`

  # Start service with command to make sure it's up before proceeding
  start_service "panel" "nc -z $SERVICE_IP 80 &> /dev/null"

  kill -9 $SPINPID &> /dev/null
  echo -ne "done."
}
